import time
def ikuntime(hour1,minute1):
	kunhour = hour1 // 2.5
	a = hour1 % 2.5
	b = a * 60 + minute1
	kunminute = b // 2.5
	if kunminute >= 60:
		kunminute -= 60
		kunhour += 1

	print("输出时间：" + str(kunhour) + "坤时" , str(kunminute) + "坤分" )
	time.sleep(5)
	exit()



from setuptools import setup, find_packages

setup(
    name='KunTimeChange',
    version='11.5',
    packages=find_packages(),
    install_requires=[
        
    ],
    author='W0518',
    author_email='2647346053@qq.com',
    description='A brief description of your package',
    license='MIT',
    keywords='sample setuptools development',
    url='https://github.com/ziyin-wang/ikuntime'
)
